# neatly

*neatly* is a package designed to facilitate the implementation of [NeuroEvolution of Augmenting Topologies (NEAT)](http://nn.cs.utexas.edu/downloads/papers/stanley.ec02.pdf) in Python.

## Installation
🚧 under construction 🚧

## Usage
🚧 under construction 🚧

## Contributing
To be completely honest, I don't know why anybody would want to contribute to this pile of hot garbage, and I don't really know how contributing works, but if you're interested email [me](mailto:seanrhee2024@u.northwestern.edu?subject=[Github]%20contributing%20to%20neatly).

## License
[MIT](https://choosealicense.com/licenses/mit/)